@@ -9,14 +9,15 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Type\Parameter
- *
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\Type
- */
+#[CoversClass(Parameter::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(Type::class)]
+#[Small]
 final class ParameterTest extends TestCase
 {
     public function testHasName(): void
