@@ -9,23 +9,21 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
-/**
- * @covers \SebastianBergmann\Type\GenericObjectType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(GenericObjectType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class GenericObjectTypeTest extends TestCase
 {
-    /**
-     * @var GenericObjectType
-     */
-    private $type;
+    private GenericObjectType $type;
 
     protected function setUp(): void
     {
@@ -53,8 +51,8 @@ final class GenericObjectTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                new ObjectType(TypeName::fromQualifiedName(stdClass::class), false)
-            )
+                new ObjectType(TypeName::fromQualifiedName(stdClass::class), false),
+            ),
         );
     }
 
@@ -64,8 +62,8 @@ final class GenericObjectTypeTest extends TestCase
 
         $this->assertTrue(
             $type->isAssignable(
-                new NullType
-            )
+                new NullType,
+            ),
         );
     }
 
@@ -73,16 +71,18 @@ final class GenericObjectTypeTest extends TestCase
     {
         $this->assertFalse(
             $this->type->isAssignable(
-                new SimpleType('bool', false)
-            )
+                new SimpleType('bool', false),
+            ),
         );
     }
 
     public function testCanBeQueriedForType(): void
     {
+        /** @phpstan-ignore method.alreadyNarrowedType */
+        $this->assertTrue($this->type->isGenericObject());
+
         $this->assertFalse($this->type->isCallable());
         $this->assertFalse($this->type->isFalse());
-        $this->assertTrue($this->type->isGenericObject());
         $this->assertFalse($this->type->isIntersection());
         $this->assertFalse($this->type->isIterable());
         $this->assertFalse($this->type->isMixed());
