@@ -9,33 +9,55 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\AnInterface;
 use SebastianBergmann\Type\TestFixture\AnotherInterface;
 use SebastianBergmann\Type\TestFixture\ClassImplementingAnInterfaceAndAnotherInterface;
 
-/**
- * @covers \SebastianBergmann\Type\IntersectionType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- *
- * @requires PHP >= 8.1
- */
+#[CoversClass(IntersectionType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class IntersectionTypeTest extends TestCase
 {
+    private IntersectionType $type;
+
     /**
-     * @psalm-var IntersectionType
+     * @return non-empty-list<array{0: bool, 1: Type, 2: IntersectionType}>
      */
-    private $type;
+    public static function assignableTypes(): array
+    {
+        return [
+            [
+                true,
+                Type::fromName(ClassImplementingAnInterfaceAndAnotherInterface::class, false),
+                new IntersectionType(
+                    Type::fromName(AnInterface::class, false),
+                    Type::fromName(AnotherInterface::class, false),
+                ),
+            ],
+            [
+                false,
+                Type::fromValue(false, false),
+                new IntersectionType(
+                    Type::fromName(AnInterface::class, false),
+                    Type::fromName(AnotherInterface::class, false),
+                ),
+            ],
+        ];
+    }
 
     protected function setUp(): void
     {
         $this->type = new IntersectionType(
             Type::fromName(AnInterface::class, false),
-            Type::fromName(AnotherInterface::class, false)
+            Type::fromName(AnotherInterface::class, false),
         );
     }
 
@@ -51,10 +73,12 @@ final class IntersectionTypeTest extends TestCase
 
     public function testCanBeQueriedForType(): void
     {
+        /** @phpstan-ignore method.alreadyNarrowedType */
+        $this->assertTrue($this->type->isIntersection());
+
         $this->assertFalse($this->type->isCallable());
         $this->assertFalse($this->type->isFalse());
         $this->assertFalse($this->type->isGenericObject());
-        $this->assertTrue($this->type->isIntersection());
         $this->assertFalse($this->type->isIterable());
         $this->assertFalse($this->type->isMixed());
         $this->assertFalse($this->type->isNever());
@@ -72,7 +96,7 @@ final class IntersectionTypeTest extends TestCase
     {
         $this->assertSame(
             AnInterface::class . '&' . AnotherInterface::class,
-            $this->type->name()
+            $this->type->name(),
         );
     }
 
@@ -80,40 +104,26 @@ final class IntersectionTypeTest extends TestCase
     {
         $this->assertSame(
             AnInterface::class . '&' . AnotherInterface::class,
-            $this->type->asString()
+            $this->type->asString(),
         );
     }
 
-    /**
-     * @dataProvider assignableProvider
-     */
+    public function testTypesOfIntersectionAreSortedByNameInStringRepresentation(): void
+    {
+        $type = new IntersectionType(
+            Type::fromName(AnotherInterface::class, false),
+            Type::fromName(AnInterface::class, false),
+        );
+
+        $this->assertSame(AnInterface::class . '&' . AnotherInterface::class, $type->asString());
+    }
+
+    #[DataProvider('assignableTypes')]
     public function testAssignableTypesAreRecognized(bool $expected, Type $type, IntersectionType $intersection): void
     {
         $this->assertSame($expected, $intersection->isAssignable($type));
     }
 
-    public function assignableProvider(): array
-    {
-        return [
-            [
-                true,
-                Type::fromName(ClassImplementingAnInterfaceAndAnotherInterface::class, false),
-                new IntersectionType(
-                    Type::fromName(AnInterface::class, false),
-                    Type::fromName(AnotherInterface::class, false)
-                ),
-            ],
-            [
-                false,
-                Type::fromValue(false, false),
-                new IntersectionType(
-                    Type::fromName(AnInterface::class, false),
-                    Type::fromName(AnotherInterface::class, false)
-                ),
-            ],
-        ];
-    }
-
     public function testDoesNotAllowNull(): void
     {
         $this->assertFalse($this->type->allowsNull());
@@ -143,7 +153,7 @@ final class IntersectionTypeTest extends TestCase
         new IntersectionType(
             Type::fromName(AnInterface::class, false),
             Type::fromName(AnInterface::class, false),
-            Type::fromName(AnotherInterface::class, false)
+            Type::fromName(AnotherInterface::class, false),
         );
     }
 }
