@@ -9,23 +9,21 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\Iterator;
 
-/**
- * @covers \SebastianBergmann\Type\IterableType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(IterableType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class IterableTypeTest extends TestCase
 {
-    /**
-     * @var IterableType
-     */
-    private $type;
+    private IterableType $type;
 
     protected function setUp(): void
     {
@@ -65,8 +63,8 @@ final class IterableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue([], false)
-            )
+                Type::fromValue([], false),
+            ),
         );
     }
 
@@ -74,8 +72,8 @@ final class IterableTypeTest extends TestCase
     {
         $this->assertTrue(
             $this->type->isAssignable(
-                Type::fromValue(new Iterator, false)
-            )
+                Type::fromValue(new Iterator, false),
+            ),
         );
     }
 
@@ -83,18 +81,20 @@ final class IterableTypeTest extends TestCase
     {
         $this->assertFalse(
             $this->type->isAssignable(
-                Type::fromValue(null, false)
-            )
+                Type::fromValue(null, false),
+            ),
         );
     }
 
     public function testCanBeQueriedForType(): void
     {
+        /** @phpstan-ignore method.alreadyNarrowedType */
+        $this->assertTrue($this->type->isIterable());
+
         $this->assertFalse($this->type->isCallable());
         $this->assertFalse($this->type->isFalse());
         $this->assertFalse($this->type->isGenericObject());
         $this->assertFalse($this->type->isIntersection());
-        $this->assertTrue($this->type->isIterable());
         $this->assertFalse($this->type->isMixed());
         $this->assertFalse($this->type->isNever());
         $this->assertFalse($this->type->isNull());
