@@ -9,33 +9,22 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Type\NullType
- * @covers \SebastianBergmann\Type\Type
- */
+#[CoversClass(NullType::class)]
+#[CoversClass(Type::class)]
+#[Small]
 final class NullTypeTest extends TestCase
 {
-    /**
-     * @var NullType
-     */
-    private $type;
-
-    protected function setUp(): void
-    {
-        $this->type = new NullType;
-    }
+    private NullType $type;
 
     /**
-     * @dataProvider assignableTypes
+     * @return non-empty-list<array{0: Type}>
      */
-    public function testIsAssignable(Type $assignableType): void
-    {
-        $this->assertTrue($this->type->isAssignable($assignableType));
-    }
-
-    public function assignableTypes(): array
+    public static function assignableTypes(): array
     {
         return [
             [new SimpleType('int', false)],
@@ -47,20 +36,32 @@ final class NullTypeTest extends TestCase
     }
 
     /**
-     * @dataProvider notAssignable
+     * @return non-empty-array<non-empty-string, array{0: Type}>
      */
-    public function testIsNotAssignable(Type $assignedType): void
-    {
-        $this->assertFalse($this->type->isAssignable($assignedType));
-    }
-
-    public function notAssignable(): array
+    public static function notAssignableTypes(): array
     {
         return [
             'void' => [new VoidType],
         ];
     }
 
+    protected function setUp(): void
+    {
+        $this->type = new NullType;
+    }
+
+    #[DataProvider('assignableTypes')]
+    public function testIsAssignable(Type $assignableType): void
+    {
+        $this->assertTrue($this->type->isAssignable($assignableType));
+    }
+
+    #[DataProvider('notAssignableTypes')]
+    public function testIsNotAssignable(Type $assignedType): void
+    {
+        $this->assertFalse($this->type->isAssignable($assignedType));
+    }
+
     public function testAllowsNull(): void
     {
         $this->assertTrue($this->type->allowsNull());
@@ -78,6 +79,9 @@ final class NullTypeTest extends TestCase
 
     public function testCanBeQueriedForType(): void
     {
+        /** @phpstan-ignore method.alreadyNarrowedType */
+        $this->assertTrue($this->type->isNull());
+
         $this->assertFalse($this->type->isCallable());
         $this->assertFalse($this->type->isFalse());
         $this->assertFalse($this->type->isGenericObject());
@@ -85,7 +89,6 @@ final class NullTypeTest extends TestCase
         $this->assertFalse($this->type->isIterable());
         $this->assertFalse($this->type->isMixed());
         $this->assertFalse($this->type->isNever());
-        $this->assertTrue($this->type->isNull());
         $this->assertFalse($this->type->isObject());
         $this->assertFalse($this->type->isSimple());
         $this->assertFalse($this->type->isStatic());
