@@ -9,37 +9,38 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\ChildClassThatExtendsClassWithMethodThatHasStaticReturnType;
 use SebastianBergmann\Type\TestFixture\ParentClassWithMethodThatHasStaticReturnType;
 use stdClass;
 
-/**
- * @covers \SebastianBergmann\Type\StaticType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(StaticType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class StaticTypeTest extends TestCase
 {
     public function testHasName(): void
     {
-        $type = new StaticType(TypeName::fromQualifiedName('vendor\project\foo'), false);
+        $type = new StaticType(TypeName::fromQualifiedName(self::class), false);
 
         $this->assertSame('static', $type->name());
     }
 
     public function testCanBeRepresentedAsString(): void
     {
-        $type = new StaticType(TypeName::fromQualifiedName('vendor\project\foo'), false);
+        $type = new StaticType(TypeName::fromQualifiedName(self::class), false);
 
         $this->assertSame('static', $type->asString());
     }
 
     public function testMayDisallowNull(): void
     {
-        $type = new StaticType(TypeName::fromQualifiedName('vendor\project\foo'), false);
+        $type = new StaticType(TypeName::fromQualifiedName(self::class), false);
 
         $this->assertFalse($type->allowsNull());
         $this->assertSame('static', $type->asString());
@@ -47,7 +48,7 @@ final class StaticTypeTest extends TestCase
 
     public function testMayAllowNull(): void
     {
-        $type = new StaticType(TypeName::fromQualifiedName('vendor\project\foo'), true);
+        $type = new StaticType(TypeName::fromQualifiedName(self::class), true);
 
         $this->assertTrue($type->allowsNull());
         $this->assertSame('?static', $type->asString());
@@ -57,7 +58,7 @@ final class StaticTypeTest extends TestCase
     {
         $type = new StaticType(
             TypeName::fromQualifiedName(ParentClassWithMethodThatHasStaticReturnType::class),
-            true
+            true,
         );
 
         $this->assertTrue($type->isAssignable(Type::fromValue(null, true)));
@@ -67,7 +68,7 @@ final class StaticTypeTest extends TestCase
     {
         $type = new StaticType(
             TypeName::fromQualifiedName(ParentClassWithMethodThatHasStaticReturnType::class),
-            false
+            false,
         );
 
         $this->assertFalse($type->isAssignable(Type::fromValue(null, true)));
@@ -77,40 +78,37 @@ final class StaticTypeTest extends TestCase
     {
         $type = new StaticType(
             TypeName::fromQualifiedName(ParentClassWithMethodThatHasStaticReturnType::class),
-            true
+            true,
         );
 
         $this->assertTrue(
             $type->isAssignable(
                 new ObjectType(
                     TypeName::fromQualifiedName(
-                        ParentClassWithMethodThatHasStaticReturnType::class
+                        ParentClassWithMethodThatHasStaticReturnType::class,
                     ),
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
-    /**
-     * @requires PHP >= 8.0
-     */
     public function testSubTypeIsAssignable(): void
     {
         $type = new StaticType(
             TypeName::fromQualifiedName(ParentClassWithMethodThatHasStaticReturnType::class),
-            true
+            true,
         );
 
         $this->assertTrue(
             $type->isAssignable(
                 new ObjectType(
                     TypeName::fromQualifiedName(
-                        ChildClassThatExtendsClassWithMethodThatHasStaticReturnType::class
+                        ChildClassThatExtendsClassWithMethodThatHasStaticReturnType::class,
                     ),
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
@@ -118,18 +116,18 @@ final class StaticTypeTest extends TestCase
     {
         $type = new StaticType(
             TypeName::fromQualifiedName(ParentClassWithMethodThatHasStaticReturnType::class),
-            true
+            true,
         );
 
         $this->assertFalse(
             $type->isAssignable(
                 new ObjectType(
                     TypeName::fromQualifiedName(
-                        stdClass::class
+                        stdClass::class,
                     ),
-                    false
-                )
-            )
+                    false,
+                ),
+            ),
         );
     }
 
@@ -137,20 +135,49 @@ final class StaticTypeTest extends TestCase
     {
         $type = new StaticType(TypeName::fromQualifiedName(stdClass::class), false);
 
-        $this->assertFalse($type->isCallable());
-        $this->assertFalse($type->isFalse());
-        $this->assertFalse($type->isGenericObject());
-        $this->assertFalse($type->isIntersection());
-        $this->assertFalse($type->isIterable());
-        $this->assertFalse($type->isMixed());
-        $this->assertFalse($type->isNever());
-        $this->assertFalse($type->isNull());
-        $this->assertFalse($type->isObject());
-        $this->assertFalse($type->isSimple());
+        /** @phpstan-ignore method.alreadyNarrowedType */
         $this->assertTrue($type->isStatic());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isCallable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isFalse());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isGenericObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIntersection());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIterable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isMixed());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNever());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNull());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isSimple());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isTrue());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnion());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnknown());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isVoid());
     }
 }
