@@ -9,38 +9,35 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\AnInterface;
 use SebastianBergmann\Type\TestFixture\AnotherInterface;
 
-/**
- * @covers \SebastianBergmann\Type\Type
- * @covers \SebastianBergmann\Type\UnionType
- *
- * @uses \SebastianBergmann\Type\IntersectionType
- * @uses \SebastianBergmann\Type\NullType
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(UnionType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(NullType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(IntersectionType::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class UnionTypeTest extends TestCase
 {
     /**
-     * @dataProvider stringRepresentationProvider
+     * @return non-empty-list<array{0: string, 1: Type}>
      */
-    public function testCanBeRepresentedAsString(string $expected, Type $type): void
-    {
-        $this->assertSame($expected, $type->asString());
-    }
-
-    public function stringRepresentationProvider(): array
+    public static function stringRepresentationProvider(): array
     {
         return [
             [
                 'bool|int',
                 new UnionType(
                     Type::fromName('bool', false),
-                    Type::fromName('int', false)
+                    Type::fromName('int', false),
                 ),
             ],
             [
@@ -48,75 +45,18 @@ final class UnionTypeTest extends TestCase
                 new UnionType(
                     new IntersectionType(
                         Type::fromName(AnInterface::class, false),
-                        Type::fromName(AnotherInterface::class, false)
+                        Type::fromName(AnotherInterface::class, false),
                     ),
-                    Type::fromName('bool', false)
+                    Type::fromName('bool', false),
                 ),
             ],
         ];
     }
 
-    public function testTypesCanBeQueried(): void
-    {
-        $bool = Type::fromName('bool', false);
-        $null = Type::fromName('null', true);
-        $type = new UnionType($bool, $null);
-
-        $this->assertSame([$bool, $null], $type->types());
-    }
-
-    public function testMayAllowNull(): void
-    {
-        $type = new UnionType(
-            Type::fromName('bool', false),
-            Type::fromName('null', true)
-        );
-
-        $this->assertTrue($type->allowsNull());
-    }
-
-    public function testMayNotAllowNull(): void
-    {
-        $type = new UnionType(
-            Type::fromName('bool', false),
-            Type::fromName('int', false)
-        );
-
-        $this->assertFalse($type->allowsNull());
-    }
-
-    public function testMayContainIntersectionType(): void
-    {
-        $type = new UnionType(
-            Type::fromName('bool', false),
-            new IntersectionType(
-                Type::fromName(AnInterface::class, false),
-                Type::fromName(AnotherInterface::class, false)
-            ),
-        );
-
-        $this->assertTrue($type->containsIntersectionTypes());
-    }
-
-    public function testMayNotContainIntersectionType(): void
-    {
-        $type = new UnionType(
-            Type::fromName('bool', false),
-            Type::fromName('int', false)
-        );
-
-        $this->assertFalse($type->containsIntersectionTypes());
-    }
-
     /**
-     * @dataProvider assignableProvider
+     * @return non-empty-list<array{0: bool, 1: Type, 2: UnionType}>
      */
-    public function testAssignableTypesAreRecognized(bool $expected, Type $type, UnionType $union): void
-    {
-        $this->assertSame($expected, $union->isAssignable($type));
-    }
-
-    public function assignableProvider(): array
+    public static function assignableProvider(): array
     {
         return [
             [
@@ -146,6 +86,70 @@ final class UnionTypeTest extends TestCase
         ];
     }
 
+    #[DataProvider('stringRepresentationProvider')]
+    public function testCanBeRepresentedAsString(string $expected, Type $type): void
+    {
+        $this->assertSame($expected, $type->asString());
+    }
+
+    public function testTypesCanBeQueried(): void
+    {
+        $bool = Type::fromName('bool', false);
+        $null = Type::fromName('null', true);
+        $type = new UnionType($bool, $null);
+
+        $this->assertSame([$bool, $null], $type->types());
+    }
+
+    public function testMayAllowNull(): void
+    {
+        $type = new UnionType(
+            Type::fromName('bool', false),
+            Type::fromName('null', true),
+        );
+
+        $this->assertTrue($type->allowsNull());
+    }
+
+    public function testMayNotAllowNull(): void
+    {
+        $type = new UnionType(
+            Type::fromName('bool', false),
+            Type::fromName('int', false),
+        );
+
+        $this->assertFalse($type->allowsNull());
+    }
+
+    public function testMayContainIntersectionType(): void
+    {
+        $type = new UnionType(
+            Type::fromName('bool', false),
+            new IntersectionType(
+                Type::fromName(AnInterface::class, false),
+                Type::fromName(AnotherInterface::class, false),
+            ),
+        );
+
+        $this->assertTrue($type->containsIntersectionTypes());
+    }
+
+    public function testMayNotContainIntersectionType(): void
+    {
+        $type = new UnionType(
+            Type::fromName('bool', false),
+            Type::fromName('int', false),
+        );
+
+        $this->assertFalse($type->containsIntersectionTypes());
+    }
+
+    #[DataProvider('assignableProvider')]
+    public function testAssignableTypesAreRecognized(bool $expected, Type $type, UnionType $union): void
+    {
+        $this->assertSame($expected, $union->isAssignable($type));
+    }
+
     public function testCannotBeCreatedFromLessThanTwoTypes(): void
     {
         $this->expectException(RuntimeException::class);
@@ -159,7 +163,7 @@ final class UnionTypeTest extends TestCase
 
         new UnionType(
             Type::fromName('int', false),
-            Type::fromName('unknown type', false)
+            Type::fromName('unknown type', false),
         );
     }
 
@@ -169,7 +173,7 @@ final class UnionTypeTest extends TestCase
 
         new UnionType(
             Type::fromName('int', false),
-            Type::fromName('void', false)
+            Type::fromName('void', false),
         );
     }
 
@@ -177,23 +181,52 @@ final class UnionTypeTest extends TestCase
     {
         $type = new UnionType(
             new SimpleType('bool', false),
-            new SimpleType('string', false)
+            new SimpleType('string', false),
         );
 
-        $this->assertFalse($type->isCallable());
-        $this->assertFalse($type->isFalse());
-        $this->assertFalse($type->isGenericObject());
-        $this->assertFalse($type->isIntersection());
-        $this->assertFalse($type->isIterable());
-        $this->assertFalse($type->isMixed());
-        $this->assertFalse($type->isNever());
-        $this->assertFalse($type->isNull());
-        $this->assertFalse($type->isObject());
-        $this->assertFalse($type->isSimple());
-        $this->assertFalse($type->isStatic());
-        $this->assertFalse($type->isTrue());
+        /** @phpstan-ignore method.alreadyNarrowedType */
         $this->assertTrue($type->isUnion());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isCallable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isFalse());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isGenericObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIntersection());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIterable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isMixed());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNever());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNull());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isSimple());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isStatic());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isTrue());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnknown());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isVoid());
     }
 }
